@@ -158,17 +158,28 @@ class UIConfig(config.Config):
 
         if cfg.width != -1 and cfg.height != -1:
             window.resize(cfg.width, cfg.height)
+
+        # Not all platforms can natively restore position, gPodder must handle it.
+        # https://github.com/gpodder/gpodder/pull/933#issuecomment-818039693
         if cfg.x == -1 or cfg.y == -1:
             window.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
         else:
             window.move(cfg.x, cfg.y)
+            # From Gtk docs: most window managers ignore requests for initial window
+            # positions (instead using a user-defined placement algorithm) and honor
+            # requests after the window has already been shown.
+            # Move it a second time after the window has been shown.
+            # The first move reduces chance of window jumping.
+            util.idle_add(window.move, cfg.x, cfg.y)
 
         # Ignore events while we're connecting to the window
         self.__ignore_window_events = True
 
+        # Get window state, correct size comes from window.get_size(),
+        # see https://developer.gnome.org/SaveWindowState/
         def _receive_configure_event(widget, event):
-            x_pos, y_pos = event.x, event.y
-            width_size, height_size = event.width, event.height
+            x_pos, y_pos = widget.get_position()
+            width_size, height_size = widget.get_size()
             maximized = bool(event.window.get_state() & Gdk.WindowState.MAXIMIZED)
             if not self.__ignore_window_events and not maximized:
                 cfg.x = x_pos
@@ -179,10 +190,8 @@ class UIConfig(config.Config):
         window.connect('configure-event', _receive_configure_event)
 
         def _receive_window_state(widget, event):
-            # ELL: why is it commented out?
-            # new_value = bool(event.new_window_state & Gdk.WindowState.MAXIMIZED)
-            # cfg.maximized = new_value
-            pass
+            new_value = bool(event.new_window_state & Gdk.WindowState.MAXIMIZED)
+            cfg.maximized = new_value
 
         window.connect('window-state-event', _receive_window_state)
 
