@@ -112,7 +112,7 @@ class gPodderChannel(BuilderWidget):
 
     def on_button_add_section_clicked(self, widget):
         text = self.show_text_edit_dialog(_('Add section'), _('New section:'),
-            affirmative_text=Gtk.STOCK_ADD)
+            affirmative_text=_('_Add'))
 
         if text is not None:
             for index, (section,) in enumerate(self.section_list):
@@ -146,8 +146,8 @@ class gPodderChannel(BuilderWidget):
             title=_('Select new podcast cover artwork'),
             parent=self.gPodderChannel,
             action=Gtk.FileChooserAction.OPEN)
-        dlg.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        dlg.add_button(Gtk.STOCK_OPEN, Gtk.ResponseType.OK)
+        dlg.add_button(_('_Cancel'), Gtk.ResponseType.CANCEL)
+        dlg.add_button(_('_Open'), Gtk.ResponseType.OK)
 
         if dlg.run() == Gtk.ResponseType.OK:
             url = dlg.get_uri()
@@ -164,7 +164,7 @@ class gPodderChannel(BuilderWidget):
         def set_cover(channel, pixbuf):
             if self.channel == channel:
                 if pixbuf is not None:
-                    self.imgCover.set_from_pixbuf(self.scale_pixbuf(pixbuf))
+                    self.imgCover.set_from_pixbuf(util.scale_pixbuf(pixbuf, self.MAX_SIZE))
                 if self.show_on_cover_load:
                     self.main_window.show()
                     self.show_on_cover_load = False
@@ -193,26 +193,10 @@ class gPodderChannel(BuilderWidget):
     def on_gPodderChannel_destroy(self, widget, *args):
         self.cover_downloader.unregister('cover-available', self.cover_download_finished)
 
-    def scale_pixbuf(self, pixbuf):
-
-        # Resize if width is too large
-        if pixbuf.get_width() > self.MAX_SIZE:
-            f = float(self.MAX_SIZE) / pixbuf.get_width()
-            (width, height) = (int(pixbuf.get_width() * f), int(pixbuf.get_height() * f))
-            pixbuf = pixbuf.scale_simple(width, height, GdkPixbuf.InterpType.BILINEAR)
-
-        # Resize if height is too large
-        if pixbuf.get_height() > self.MAX_SIZE:
-            f = float(self.MAX_SIZE) / pixbuf.get_height()
-            (width, height) = (int(pixbuf.get_width() * f), int(pixbuf.get_height() * f))
-            pixbuf = pixbuf.scale_simple(width, height, GdkPixbuf.InterpType.BILINEAR)
-
-        return pixbuf
-
     # Title editing callbacks
     def on_title_edit_button_clicked(self, button):
         self.title_save_button_saves = True
-        self.title_save_button.set_label(_("Save"))
+        self.title_save_button.set_label(_("_Save"))
         self.title_stack.set_visible_child(self.title_edit_box)
         self.title_entry.set_text(self.title_label.get_text())
         self.title_entry.grab_focus()
@@ -220,7 +204,7 @@ class gPodderChannel(BuilderWidget):
     def on_title_entry_changed(self, entry):
         if len(entry.get_text()) > 0:
             self.title_save_button_saves = True
-            self.title_save_button.set_label(_("Save"))
+            self.title_save_button.set_label(_("_Save"))
         else:
             self.title_save_button_saves = False
             self.title_save_button.set_label(_("Cancel"))
