@@ -35,6 +35,24 @@ from gpodder import download, util
 _ = gpodder.gettext
 
 
+class DequeueRequest:
+    def __init__(self):
+        self.cv = threading.Condition()
+        self.value = None
+        self.resolved = False
+
+    def dequeue(self):
+        with self.cv:
+            self.cv.wait_for(lambda: self.resolved)
+            return self.value
+
+    def resolve(self, value):
+        self.value = value
+        self.resolved = True
+        with self.cv:
+            self.cv.notify()
+
+
 class DownloadStatusModel(Gtk.ListStore):
     # Symbolic names for our columns, so we know what we're up to
     C_TASK, C_NAME, C_URL, C_PROGRESS, C_PROGRESS_TEXT, C_ICON_NAME = list(range(6))
@@ -44,19 +62,20 @@ class DownloadStatusModel(Gtk.ListStore):
     def __init__(self):
         Gtk.ListStore.__init__(self, object, str, str, int, str, str)
 
-        self.set_downloading_access = threading.RLock()
-
         # Set up stock icon IDs for tasks
         self._status_ids = collections.defaultdict(lambda: None)
         self._status_ids[download.DownloadTask.DOWNLOADING] = 'go-down'
-        self._status_ids[download.DownloadTask.DONE] = Gtk.STOCK_APPLY
+        self._status_ids[download.DownloadTask.DONE] = 'object-select-symbolic'
         self._status_ids[download.DownloadTask.FAILED] = 'dialog-error'
+        self._status_ids[download.DownloadTask.CANCELLING] = 'media-playback-stop'
         self._status_ids[download.DownloadTask.CANCELLED] = 'media-playback-stop'
+        self._status_ids[download.DownloadTask.PAUSING] = 'media-playback-pause'
         self._status_ids[download.DownloadTask.PAUSED] = 'media-playback-pause'
 
     def _format_message(self, episode, message, podcast):
         episode = html.escape(episode)
         podcast = html.escape(podcast)
+        message = html.escape(message)
         return '%s\n<small>%s - %s</small>' % (episode, message, podcast)
 
     def request_update(self, iter, task=None):
@@ -110,20 +129,34 @@ class DownloadStatusModel(Gtk.ListStore):
         iter = self.append()
         self.request_update(iter, task)
 
-    def register_task(self, task):
-        util.idle_add(self.__add_new_task, task)
+    def register_task(self, task, background=True):
+        if background:
+            util.idle_add(self.__add_new_task, task)
+        else:
+            self.__add_new_task(task)
+
+    def queue_task(self, task):
+        with task:
+            if task.status in (task.NEW, task.FAILED, task.CANCELLED, task.PAUSED):
+                task.status = task.QUEUED
+                task.set_episode_download_task()
 
     def tell_all_tasks_to_quit(self):
         for row in self:
             task = row[DownloadStatusModel.C_TASK]
             if task is not None:
-                # Pause currently-running (and queued) downloads
-                if task.status in (task.QUEUED, task.DOWNLOADING):
-                    task.status = task.PAUSED
+                with task:
+                    # Pause currently queued downloads
+                    if task.status == task.QUEUED:
+                        task.status = task.PAUSED
 
-                # Delete cancelled and failed downloads
-                if task.status in (task.CANCELLED, task.FAILED):
-                    task.removed_from_list()
+                    # Request pause of currently running downloads
+                    elif task.status == task.DOWNLOADING:
+                        task.status = task.PAUSING
+
+                    # Delete cancelled and failed downloads
+                    elif task.status in (task.CANCELLED, task.FAILED):
+                        task.removed_from_list()
 
     def are_downloads_in_progress(self):
         """
@@ -145,25 +178,29 @@ class DownloadStatusModel(Gtk.ListStore):
     def available_work_count(self):
         return len(list(self._work_gen()))
 
+    def __get_next(self, dqr):
+        try:
+            task = next(self._work_gen())
+            # this is the only thread accessing the list store, so it's safe
+            # to assume a) the task is still queued and b) we can transition to downloading
+            task.status = task.DOWNLOADING
+        except StopIteration as e:
+            task = None
+        # hand the task off to the worker thread
+        dqr.resolve(task)
+
+    # get the next task to download. this proxies the request to the main thread,
+    # as only the main thread is allowed to manipulate the list store.
     def get_next(self):
-        with self.set_downloading_access:
-            result = next(self._work_gen())
-            self.set_downloading(result)
-        return result
+        dqr = DequeueRequest()
+        util.idle_add(self.__get_next, dqr)
+        return dqr.dequeue()
 
     def _work_gen(self):
         return (task for task in
                 (row[DownloadStatusModel.C_TASK] for row in self)
                 if task.status == task.QUEUED)
 
-    def set_downloading(self, task):
-        with self.set_downloading_access:
-            if task.status is task.DOWNLOADING:
-                # Task was already set as DOWNLOADING by get_next
-                return False
-            task.status = task.DOWNLOADING
-            return True
-
 
 class DownloadTaskMonitor(object):
     """A helper class that abstracts download events"""
