@@ -17,20 +17,20 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import html
+
 from gi.repository import Gtk
-import cgi
 
 import gpodder
+from gpodder.gtkui.config import ConfigModel
+from gpodder.gtkui.interface.common import BuilderWidget
 
 _ = gpodder.gettext
 
-from gpodder.gtkui.config import ConfigModel
-
-from gpodder.gtkui.interface.common import BuilderWidget
-
 
 class gPodderConfigEditor(BuilderWidget):
     def new(self):
+        self.gPodderConfigEditor.set_transient_for(self.parent_widget)
         name_column = Gtk.TreeViewColumn(_('Setting'))
         name_renderer = Gtk.CellRendererText()
         name_column.pack_start(name_renderer, True)
@@ -41,6 +41,8 @@ class gPodderConfigEditor(BuilderWidget):
 
         value_column = Gtk.TreeViewColumn(_('Set to'))
         value_check_renderer = Gtk.CellRendererToggle()
+        # align left otherwise the checkbox is very far away and not visible
+        value_check_renderer.set_alignment(0, 0.5)
         value_column.pack_start(value_check_renderer, False)
         value_column.add_attribute(value_check_renderer, 'active', 7)
         value_column.add_attribute(value_check_renderer, 'visible', 6)
@@ -64,6 +66,8 @@ class gPodderConfigEditor(BuilderWidget):
         self.configeditor.set_model(self.filter)
         self.configeditor.set_rules_hint(True)
 
+        self._config.connect_gtk_window(self.main_window, 'config_editor', True)
+
     def visible_func(self, model, iter, user_data=None):
         text = self.entryFilter.get_text().lower()
         if text == '':
@@ -81,9 +85,9 @@ class gPodderConfigEditor(BuilderWidget):
 
         if not self._config.update_field(name, new_text):
             message = _('Cannot set %(field)s to %(value)s. Needed data type: %(datatype)s')
-            d = {'field': cgi.escape(name),
-                 'value': cgi.escape(new_text),
-                 'datatype': cgi.escape(type_cute)}
+            d = {'field': html.escape(name),
+                 'value': html.escape(new_text),
+                 'datatype': html.escape(type_cute)}
             self.notification(message % d, _('Error setting option'))
 
     def value_toggled(self, renderer, path):
